@@ -8,17 +8,20 @@ app.pages.Contacts = Backbone.View.extend({
     "click #contacts_visibility_toggle" : "toggleContactVisibility",
     "click #chat_privilege_toggle" : "toggleChatPrivilege",
     "click #change_aspect_name" : "showAspectNameForm",
-    "keyup #contact_list_search" : "searchContactList"
+    "click .conversation_button": "showMessageModal",
+    "click #invitations-button": "showInvitationsModal"
   },
 
   initialize: function(opts) {
-    this.visibility_toggle = $("#contacts_visibility_toggle .entypo");
-    this.chat_toggle = $("#chat_privilege_toggle .entypo");
+    this.visibilityToggle = $("#contacts_visibility_toggle i");
+    this.chatToggle = $("#chat_privilege_toggle i");
     this.stream = opts.stream;
     this.stream.render();
-    $("#people_stream.contacts .header .entypo").tooltip({"placement": "bottom"});
+    $("#people_stream.contacts .header i").tooltip({"placement": "bottom"});
     $(document).on("ajax:success", "form.edit_aspect", this.updateAspectName);
     app.events.on("aspect:create", function(){ window.location.reload() });
+    app.events.on("aspect_membership:create", this.addAspectMembership, this);
+    app.events.on("aspect_membership:destroy", this.removeAspectMembership, this);
 
     this.aspectCreateView = new app.views.AspectCreate({ el: $("#newAspectContainer") });
     this.aspectCreateView.render();
@@ -27,14 +30,14 @@ app.pages.Contacts = Backbone.View.extend({
   },
 
   toggleChatPrivilege: function() {
-    if (this.chat_toggle.hasClass("enabled")) {
-      this.chat_toggle.tooltip("destroy")
+    if (this.chatToggle.hasClass("enabled")) {
+      this.chatToggle.tooltip("destroy")
                       .removeClass("enabled")
                       .removeAttr("data-original-title")
                       .attr("title", Diaspora.I18n.t("contacts.aspect_chat_is_not_enabled"))
                       .tooltip({"placement": "bottom"});
     } else {
-      this.chat_toggle.tooltip("destroy")
+      this.chatToggle.tooltip("destroy")
                       .addClass("enabled")
                       .removeAttr("data-original-title")
                       .attr("title", Diaspora.I18n.t("contacts.aspect_chat_is_enabled"))
@@ -43,17 +46,17 @@ app.pages.Contacts = Backbone.View.extend({
   },
 
   toggleContactVisibility: function() {
-    if (this.visibility_toggle.hasClass("lock-open")) {
-      this.visibility_toggle.removeClass("lock-open")
-                            .addClass("lock")
+    if (this.visibilityToggle.hasClass("entypo-lock-open")) {
+      this.visibilityToggle.removeClass("entypo-lock-open")
+                            .addClass("entypo-lock")
                             .tooltip("destroy")
                             .removeAttr("data-original-title")
                             .attr("title", Diaspora.I18n.t("contacts.aspect_list_is_not_visible"))
                             .tooltip({"placement": "bottom"});
     }
     else {
-      this.visibility_toggle.removeClass("lock")
-                            .addClass("lock-open")
+      this.visibilityToggle.removeClass("entypo-lock")
+                            .addClass("entypo-lock-open")
                             .tooltip("destroy")
                             .removeAttr("data-original-title")
                             .attr("title", Diaspora.I18n.t("contacts.aspect_list_is_visible"))
@@ -75,13 +78,17 @@ app.pages.Contacts = Backbone.View.extend({
     $(".header > h3").show();
   },
 
-  searchContactList: function(e) {
-    this.stream.search($(e.target).val());
+  showMessageModal: function(){
+    app.helpers.showModal("#conversationModal");
+  },
+
+  showInvitationsModal: function() {
+    app.helpers.showModal("#invitationsModal");
   },
 
   setupAspectSorting: function() {
-    $("#aspect_nav .nav").sortable({
-      items: "li.aspect[data-aspect-id]",
+    $("#aspect_nav .list-group").sortable({
+      items: "a.aspect[data-aspect-id]",
       update: function() {
         $("#aspect_nav .ui-sortable").addClass("syncing");
         var data = JSON.stringify({ ordered_aspect_ids: $(this).sortable("toArray", { attribute: "data-aspect-id" }) });
@@ -92,7 +99,51 @@ app.pages.Contacts = Backbone.View.extend({
       revert: true,
       helper: "clone"
     });
+  },
+
+  updateBadgeCount: function(selector, change) {
+    var count = parseInt($("#aspect_nav " + selector + " .badge").text(), 10);
+    $("#aspect_nav " + selector + " .badge").text(count + change);
+  },
+
+  addAspectMembership: function(data) {
+    if(data.startSharing) {
+      this.updateBadgeCount(".all_aspects", 1);
+
+      var contact = this.stream.collection.find(function(c) {
+        return c.get("person").id === data.membership.personId;
+      });
+
+      if(contact && contact.person.get("relationship") === "sharing") {
+        contact.person.set({relationship: "mutual"});
+        this.updateBadgeCount(".only_sharing", -1);
+      }
+      else if(contact && contact.person.get("relationship") === "not_sharing") {
+        contact.person.set({relationship: "receiving"});
+        this.updateBadgeCount(".all_contacts", 1);
+      }
+    }
+    this.updateBadgeCount("[data-aspect-id='" + data.membership.aspectId + "']", 1);
+  },
+
+  removeAspectMembership: function(data) {
+    if(data.stopSharing) {
+      this.updateBadgeCount(".all_aspects", -1);
+
+      var contact = this.stream.collection.find(function(c) {
+        return c.get("person").id === data.membership.personId;
+      });
+
+      if(contact && contact.person.get("relationship") === "mutual") {
+        contact.person.set({relationship: "sharing"});
+        this.updateBadgeCount(".only_sharing", 1);
+      }
+      else if(contact && contact.person.get("relationship") === "receiving") {
+        contact.person.set({relationship: "not_sharing"});
+        this.updateBadgeCount(".all_contacts", -1);
+      }
+    }
+    this.updateBadgeCount("[data-aspect-id='" + data.membership.aspectId + "']", -1);
   }
 });
 // @license-end
-
