@@ -16,7 +16,7 @@ app.views.BackToTop = Backbone.View.extend({
   },
 
   toggleVisibility: function() {
-    if($("html, body").scrollTop() > 1000) {
+    if($(document).scrollTop() > 1000) {
       $("#back-to-top").addClass("visible");
     } else {
       $("#back-to-top").removeClass("visible");
