@@ -5,26 +5,32 @@ app.views.LikesInfo = app.views.Base.extend({
   templateName : "likes-info",
 
   events : {
-    "click .expand_likes" : "showAvatars"
+    "click .expand-likes" : "showAvatars"
   },
 
   tooltipSelector : ".avatar",
 
   initialize : function() {
     this.model.interactions.bind('change', this.render, this);
+    this.displayAvatars = false;
   },
 
   presenter : function() {
     return _.extend(this.defaultPresenter(), {
       likes : this.model.interactions.likes.toJSON(),
       likesCount : this.model.interactions.likesCount(),
-      likes_fetched : this.model.interactions.get("fetched"),
+      displayAvatars : this.model.interactions.get("fetched") && this.displayAvatars
     });
   },
 
   showAvatars : function(evt){
     if(evt) { evt.preventDefault() }
-    this.model.interactions.fetch();
+    this.displayAvatars = true;
+    if(!this.model.interactions.get("fetched")){
+      this.model.interactions.fetch();
+    } else {
+      this.model.interactions.trigger("change");
+    }
   }
 });
 // @license-end
