@@ -45,7 +45,7 @@ class ConversationsController < ApplicationController
 
     @response = {}
     if person_ids.present? && @conversation.save
-      Postzord::Dispatcher.build(current_user, @conversation).post
+      Diaspora::Federation::Dispatcher.defer_dispatch(current_user, @conversation)
       @response[:success] = true
       @response[:message] = I18n.t('conversations.create.sent')
       @response[:conversation_id] = @conversation.id
@@ -104,7 +104,7 @@ class ConversationsController < ApplicationController
   private
 
   def contacts_data
-    current_user.contacts.sharing.joins(person: :profile)
+    current_user.contacts.mutual.joins(person: :profile)
       .pluck(*%w(contacts.id profiles.first_name profiles.last_name people.diaspora_handle))
       .map {|contact_id, *name_attrs|
         {value: contact_id, name: ERB::Util.h(Person.name_from_attrs(*name_attrs)) }
