@@ -3,12 +3,14 @@
 #   the COPYRIGHT file.
 
 class PeopleController < ApplicationController
+  include GonHelper
+
   before_action :authenticate_user!, except: %i(show stream hovercard)
   before_action :find_person, only: %i(show stream hovercard)
+  before_action :authenticate_if_remote_profile!, only: %i(show stream)
 
-  respond_to :html, :except => [:tag_index]
+  respond_to :html
   respond_to :json, :only => [:index, :show]
-  respond_to :js, :only => [:tag_index]
 
   rescue_from ActiveRecord::RecordNotFound do
     render :file => Rails.root.join('public', '404').to_s,
@@ -61,44 +63,32 @@ class PeopleController < ApplicationController
       self.formats = self.formats + [:html]
       @answer_html = render_to_string :partial => 'people/person', :locals => @hashes.first
     end
-    render :json => { :search_count => @people.count, :search_html => @answer_html }.to_json
-  end
-
-
-  def tag_index
-    profiles = Profile.tagged_with(params[:name]).where(:searchable => true).select('profiles.id, profiles.person_id')
-    @people = Person.where(:id => profiles.map{|p| p.person_id}).paginate(:page => params[:page], :per_page => 15)
-    respond_with @people
+    render json: {search_html: @answer_html, contacts: gon.preloads[:contacts]}.to_json
   end
 
   # renders the persons user profile page
   def show
     mark_corresponding_notifications_read if user_signed_in?
-
-    @person_json = PersonPresenter.new(@person, current_user).full_hash_with_profile
+    @presenter = PersonPresenter.new(@person, current_user)
 
     respond_to do |format|
       format.all do
         if user_signed_in?
           @contact = current_user.contact_for(@person)
         end
-        gon.preloads[:person] = @person_json
-        gon.preloads[:photos] = {
-          count: Photo.visible(current_user, @person).count(:all)
-        }
-        gon.preloads[:contacts] = {
-          count: Contact.contact_contacts_for(current_user, @person).count(:all),
-        }
-        respond_with @person, layout: "with_header"
+        gon.preloads[:person] = @presenter.as_json
+        gon.preloads[:photos_count] = Photo.visible(current_user, @person).count(:all)
+        gon.preloads[:contacts_count] = Contact.contact_contacts_for(current_user, @person).count(:all)
+        respond_with @presenter, layout: "with_header"
       end
 
       format.mobile do
         @post_type = :all
         person_stream
-        respond_with @person
+        respond_with @presenter
       end
 
-      format.json { render json: @person_json }
+      format.json { render json: @presenter.as_json }
     end
   end
 
@@ -120,7 +110,7 @@ class PeopleController < ApplicationController
       end
 
       format.json do
-        render :json => HovercardPresenter.new(@person)
+        render json: PersonPresenter.new(@person, current_user).hovercard
       end
     end
   end
@@ -144,13 +134,9 @@ class PeopleController < ApplicationController
         if @person
           @contact = current_user.contact_for(@person)
           @contacts_of_contact = Contact.contact_contacts_for(current_user, @person)
-          gon.preloads[:person] = PersonPresenter.new(@person, current_user).full_hash_with_profile
-          gon.preloads[:photos] = {
-            count: Photo.visible(current_user, @person).count(:all)
-          }
-          gon.preloads[:contacts] = {
-            count: @contacts_of_contact.count(:all),
-          }
+          gon.preloads[:person] = PersonPresenter.new(@person, current_user).as_json
+          gon.preloads[:photos_count] = Photo.visible(current_user, @person).count(:all)
+          gon.preloads[:contacts_count] = @contacts_of_contact.count(:all)
           @contacts_of_contact = @contacts_of_contact.paginate(page: params[:page], per_page: (params[:limit] || 15))
           @hashes = hashes_for_people @contacts_of_contact, @aspects
           respond_with @person, layout: "with_header"
@@ -162,21 +148,6 @@ class PeopleController < ApplicationController
     end
   end
 
-  # shows the dropdown list of aspects the current user has set for the given person.
-  # renders "thats you" in case the current user views himself
-  def aspect_membership_dropdown
-    @person = Person.find_by_guid(params[:person_id])
-
-    # you are not a contact of yourself...
-    return render :text => I18n.t('people.person.thats_you') if @person == current_user.person
-
-    @contact = current_user.contact_for(@person) || Contact.new
-    @aspect = :profile if params[:create]  # let aspect dropdown create new aspects
-    size = params[:size] || "small"
-
-    render :partial => 'aspect_membership_dropdown', :locals => {:contact => @contact, :person => @person, :hang => 'left', :size => size}
-  end
-
   private
 
   def find_person
@@ -192,23 +163,19 @@ class PeopleController < ApplicationController
         })
       end
 
-    # view this profile on the home pod, if you don't want to sign in...
-    authenticate_user! if remote_profile_with_no_user_session?
     raise ActiveRecord::RecordNotFound if @person.nil?
     raise Diaspora::AccountClosed if @person.closed_account?
   end
 
   def hashes_for_people(people, aspects)
-    ids = people.map{|p| p.id}
-    contacts = {}
-    Contact.unscoped.where(:user_id => current_user.id, :person_id => ids).each do |contact|
-      contacts[contact.person_id] = contact
-    end
-
-    people.map{|p|
-      {:person => p,
-        :contact => contacts[p.id],
-        :aspects => aspects}
+    people.map {|person|
+      {
+        person:  person,
+        contact: current_user.contact_for(person) || Contact.new(person: person),
+        aspects: aspects
+      }.tap {|hash|
+        gon_load_contact(hash[:contact])
+      }
     }
   end
 
@@ -217,11 +184,12 @@ class PeopleController < ApplicationController
   end
 
   def diaspora_id?(query)
-    !query.try(:match, /^(\w)*@([a-zA-Z0-9]|[-]|[.]|[:])*$/).nil?
+    !(query.nil? || query.lstrip.empty?) && Validation::Rule::DiasporaId.new.valid_value?(query)
   end
 
-  def remote_profile_with_no_user_session?
-    @person.try(:remote?) && !user_signed_in?
+  # view this profile on the home pod, if you don't want to sign in...
+  def authenticate_if_remote_profile!
+    authenticate_user! if @person.try(:remote?)
   end
 
   def mark_corresponding_notifications_read
