@@ -39,27 +39,19 @@ module InterimStreamHackinessHelper
     end
   end
 
+  def publisher_method(method)
+    @stream.try(:publisher).try(method) == true
+  end
+
   def publisher_open
-    if defined?(@stream)
-      @stream.publisher.open?
-    else
-      false
-    end
+    publisher_method(:open)
   end
 
   def publisher_public
-    if defined?(@stream)
-      @stream.publisher.public?
-    else
-      false
-    end
+    publisher_method(:public)
   end
 
   def publisher_explain
-    if defined?(@stream)
-      @stream.publisher.public?
-    else
-      false
-    end
+    publisher_method(:explain)
   end
 end
