@@ -1,16 +1,14 @@
 class Poll < ActiveRecord::Base
   include Diaspora::Federated::Base
-  include Diaspora::Guid
+  include Diaspora::Fields::Guid
 
   belongs_to :status_message
   has_many :poll_answers, -> { order 'id ASC' }
   has_many :poll_participations
-
-  xml_attr :question
-  xml_attr :poll_answers, :as => [PollAnswer]
+  has_one :author, through: :status_message
 
   #forward some requests to status message, because a poll is just attached to a status message and is not sharable itself
-  delegate :author, :author_id, :diaspora_handle, :public?, :subscribers, to: :status_message
+  delegate :author_id, :diaspora_handle, :public?, :subscribers, to: :status_message
 
   validate :enough_poll_answers
   validates :question, presence: true
