@@ -12,7 +12,6 @@ class StatisticsPresenter < NodeInfoPresenter
     base_data.merge(user_counts)
              .merge(post_counts)
              .merge(comment_counts)
-             .merge(legacy_services)
   end
 
   def base_data
@@ -47,10 +46,4 @@ class StatisticsPresenter < NodeInfoPresenter
       "local_comments" => local_comments
     }
   end
-
-  def legacy_services
-    Configuration::KNOWN_SERVICES.each_with_object({}) {|service, result|
-      result[service.to_s] = AppConfig.show_service?(service, nil)
-    }
-  end
 end
