@@ -5,9 +5,6 @@ module Export
                :public,
                :diaspora_handle,
                :type,
-               :image_url,
-               :image_height,
-               :image_width,
                :likes_count,
                :comments_count,
                :reshares_count,
