@@ -1,7 +1,7 @@
 module Workers
   module Mail
     class ConfirmEmail < Base
-      sidekiq_options queue: :mail
+      sidekiq_options queue: :low
       
       def perform(user_id)
         Notifier.confirm_email(user_id).deliver_now
