@@ -6,7 +6,7 @@
 module Workers
   module Mail
     class Mentioned < Base
-      sidekiq_options queue: :mail
+      sidekiq_options queue: :low
       
       def perform(recipient_id, actor_id, target_id)
         Notifier.mentioned( recipient_id, actor_id, target_id).deliver_now
