@@ -4,7 +4,7 @@
 #
 module Workers
   class PostToService < Base
-    sidekiq_options queue: :http_service
+    sidekiq_options queue: :medium
 
     def perform(service_id, post_id, url)
       service = Service.find_by_id(service_id)
