@@ -4,7 +4,7 @@
 
 module Workers
   class RemoveOldUser < Base
-    sidekiq_options queue: :maintenance
+    sidekiq_options queue: :low
     
     def safe_remove_after
       # extra safety time to compare in addition to remove_after
@@ -24,4 +24,4 @@ module Workers
       end
     end
   end 
-end
\ No newline at end of file
+end
