@@ -5,9 +5,12 @@ DiasporaFederation.configure do |config|
 
   config.certificate_authorities = AppConfig.environment.certificate_authorities.get
 
+  config.http_concurrency = AppConfig.settings.typhoeus_concurrency.to_i
+  config.http_verbose = AppConfig.settings.typhoeus_verbose?
+
   config.define_callbacks do
-    on :fetch_person_for_webfinger do |handle|
-      person = Person.find_local_by_diaspora_handle(handle)
+    on :fetch_person_for_webfinger do |diaspora_id|
+      person = Person.where(diaspora_handle: diaspora_id, closed_account: false).where.not(owner: nil).first
       if person
         DiasporaFederation::Discovery::WebFinger.new(
           acct_uri:      "acct:#{person.diaspora_handle}",
@@ -25,7 +28,7 @@ DiasporaFederation.configure do |config|
     end
 
     on :fetch_person_for_hcard do |guid|
-      person = Person.find_local_by_guid(guid)
+      person = Person.where(guid: guid, closed_account: false).where.not(owner: nil).take
       if person
         DiasporaFederation::Discovery::HCard.new(
           guid:             person.guid,
@@ -47,7 +50,7 @@ DiasporaFederation.configure do |config|
       # find existing person or create a new one
       person_entity = Person.find_by(diaspora_handle: person.diaspora_id) ||
         Person.new(diaspora_handle: person.diaspora_id, guid: person.guid,
-                   serialized_public_key: person.exported_key, url: person.url)
+                   serialized_public_key: person.exported_key, pod: Pod.find_or_create_by(url: person.url))
 
       profile = person.profile
       profile_entity = person_entity.profile ||= Profile.new
@@ -63,64 +66,69 @@ DiasporaFederation.configure do |config|
       person_entity.save!
     end
 
-    on :fetch_private_key_by_diaspora_id do |diaspora_id|
+    on :fetch_private_key do |diaspora_id|
       key = Person.where(diaspora_handle: diaspora_id).joins(:owner).pluck(:serialized_private_key).first
-      OpenSSL::PKey::RSA.new key unless key.nil?
+      OpenSSL::PKey::RSA.new(key) unless key.nil?
     end
 
-    on :fetch_author_private_key_by_entity_guid do |entity_type, guid|
-      key = entity_type.constantize.where(guid: guid).joins(author: :owner).pluck(:serialized_private_key).first
-      OpenSSL::PKey::RSA.new key unless key.nil?
+    on :fetch_public_key do |diaspora_id|
+      key = Person.find_or_fetch_by_identifier(diaspora_id).serialized_public_key
+      OpenSSL::PKey::RSA.new(key) unless key.nil?
     end
 
-    on :fetch_public_key_by_diaspora_id do |diaspora_id|
-      key = Person.where(diaspora_handle: diaspora_id).pluck(:serialized_public_key).first
-      OpenSSL::PKey::RSA.new key unless key.nil?
+    on :fetch_related_entity do |entity_type, guid|
+      entity = Diaspora::Federation::Mappings.model_class_for(entity_type).find_by(guid: guid)
+      Diaspora::Federation::Entities.related_entity(entity) if entity
     end
 
-    on :fetch_author_public_key_by_entity_guid do |entity_type, guid|
-      key = entity_type.constantize.where(guid: guid).joins(:author).pluck(:serialized_public_key).first
-      OpenSSL::PKey::RSA.new key unless key.nil?
+    on :queue_public_receive do |xml, legacy=false|
+      Workers::ReceivePublic.perform_async(xml, legacy)
     end
 
-    on :entity_author_is_local? do |entity_type, guid|
-      entity_type.constantize.where(guid: guid).joins(author: :owner).exists?
-    end
-
-    on :fetch_entity_author_id_by_guid do |entity_type, guid|
-      entity_type.constantize.where(guid: guid).joins(:author).pluck(:diaspora_handle).first
-    end
-
-    on :queue_public_receive do |xml|
-      Workers::ReceiveUnencryptedSalmon.perform_async(xml)
-    end
-
-    on :queue_private_receive do |guid, xml|
+    on :queue_private_receive do |guid, xml, legacy=false|
       person = Person.find_by_guid(guid)
 
-      if person.nil? || person.owner_id.nil?
-        false
-      else
-        Workers::ReceiveEncryptedSalmon.perform_async(person.owner.id, xml)
-        true
+      (person.present? && person.owner_id.present?).tap do |user_found|
+        Workers::ReceivePrivate.perform_async(person.owner.id, xml, legacy) if user_found
       end
     end
 
-    on :receive_entity do
-      # TODO
+    on :receive_entity do |entity, recipient_id|
+      case entity
+      when DiasporaFederation::Entities::AccountDeletion
+        Diaspora::Federation::Receive.account_deletion(entity)
+      when DiasporaFederation::Entities::Retraction
+        Diaspora::Federation::Receive.retraction(entity, recipient_id)
+      else
+        persisted = Diaspora::Federation::Receive.perform(entity)
+        Workers::ReceiveLocal.perform_async(persisted.class.to_s, persisted.id, [recipient_id].compact) if persisted
+      end
     end
 
     on :fetch_public_entity do |entity_type, guid|
-      entity = entity_type.constantize.find_by(guid: guid, public: true)
-      Diaspora::Federation.post(entity) if entity.is_a? Post
+      entity = Diaspora::Federation::Mappings.model_class_for(entity_type).find_by(guid: guid, public: true)
+      Diaspora::Federation::Entities.post(entity) if entity.is_a? Post
     end
 
     on :fetch_person_url_to do |diaspora_id, path|
-      Person.find_by(diaspora_handle: diaspora_id).send(:url_to, path)
+      Person.find_or_fetch_by_identifier(diaspora_id).url_to(path)
     end
 
-    on :update_pod do
-      # TODO
+    on :update_pod do |url, status|
+      pod = Pod.find_or_create_by(url: url)
+
+      if status.is_a? Symbol
+        pod.status = Pod::CURL_ERROR_MAP.fetch(status, :unknown_error)
+        pod.error = "FederationError: #{status}"
+      elsif status >= 200 && status < 300
+        pod.status = :no_errors unless Pod.statuses[pod.status] == Pod.statuses[:version_failed]
+      else
+        pod.status = :http_failed
+        pod.error = "FederationError: HTTP status code was: #{status}"
+      end
+      pod.update_offline_since
+
+      pod.save
     end
   end
 end
