@@ -15,9 +15,9 @@ module WillPaginate
 
     class BootstrapLinkRenderer < LinkRenderer
       protected
-      
+
       def html_container(html)
-        tag :div, tag(:ul, html), container_attributes
+        tag :div, tag(:ul, html, class: "pagination"), container_attributes
       end
 
       def page_number(page)
