@@ -46,8 +46,9 @@ Given /^I have been invited by an admin$/ do
   i.send!
 end
 
-Given /^I have been invited by bob$/ do
-  @inviter = FactoryGirl.create(:user, :email => 'bob@bob.bob')
+Given /^I have been invited by "([^\"]+)"$/ do |email|
+  AppConfig.settings.enable_registrations = false
+  @inviter = User.find_by_email(email)
   @inviter_invite_count = @inviter.invitation_code.count
   i = EmailInviter.new("new_invitee@example.com", @inviter)
   i.send!
@@ -118,8 +119,10 @@ Then /^I should have (\d) contacts? in "([^"]*)"$/ do |n_contacts, aspect_name|
   @me.aspects.where(:name => aspect_name).first.contacts.count.should == n_contacts.to_i
 end
 
-When /^I (?:add|remove) the person (?:to|from) my "([^\"]*)" aspect$/ do |aspect_name|
-  toggle_aspect_via_ui(aspect_name)
+When /^I (?:add|remove) the person (?:to|from) my "([^\"]*)" aspect(?: within "([^"]*)")?$/ do |aspect_name, within_selector| # rubocop:disable Metrics/LineLength
+  with_scope(within_selector) do
+    toggle_aspect_via_ui(aspect_name)
+  end
 end
 
 When /^I post a status with the text "([^\"]*)"$/ do |text|
@@ -156,9 +159,14 @@ Then /^I should not see "([^\"]*)" in the last sent email$/ do |text|
   email_text.should_not match(text)
 end
 
-When /^"([^\"]+)" has posted a status message with a photo$/ do |email|
+When /^"([^\"]+)" has posted a (public )?status message with a photo$/ do |email, public_status|
   user = User.find_for_database_authentication(:username => email)
-  post = FactoryGirl.create(:status_message_with_photo, :text => "Look at this dog", :author => user.person)
+  post = FactoryGirl.create(
+    :status_message_with_photo,
+    text:   "Look at this dog",
+    author: user.person,
+    public: public_status.present?
+  )
   [post, post.photos.first].each do |p|
     user.add_to_streams(p, user.aspects)
     user.dispatch_post(p)
@@ -200,20 +208,14 @@ When /^I view "([^\"]*)"'s first post$/ do |email|
   visit post_path(post)
 end
 
-Given /^I visit alice's invitation code url$/ do
-  @alice ||= FactoryGirl.create(:user, :username => 'alice', :getting_started => false)
-  invite_code  = InvitationCode.find_or_create_by(user_id: @alice.id)
-  visit invite_code_path(invite_code)
-end
-
 When /^I fill in the new user form/ do
   fill_in_new_user_form
 end
 
-And /^I should be able to friend Alice$/ do
-  alice = User.find_by_username 'alice'
-  step 'I should see "Add contact"'
-  step "I should see \"#{alice.name}\""
+And /^I should be able to friend "([^\"]*)"$/ do |email|
+  user = User.find_by_email(email)
+  step 'I should see a ".aspect_dropdown"'
+  step "I should see \"#{user.name}\""
 end
 
 When /^I click the sign in button$/ do
@@ -225,5 +227,9 @@ Given /^I did request my photos$/ do
 end
 
 Then /^I should get a zipped file$/ do
-  expect(DownloadHelpers.download).to end_with("zip")
+  expect(page.response_headers["Content-Type"]).to eq("application/zip")
+end
+
+And /^a person with ID "([^\"]*)" has been discovered$/ do |diaspora_id|
+  FactoryGirl.create(:person, diaspora_handle: diaspora_id)
 end
