@@ -4,20 +4,32 @@
 
 module Workers
   class PublishToHub < Base
-    def perform(_sender_atom_url)
+    def perform(*_args)
       # don't publish to pubsubhubbub in cucumber
     end
   end
 
-  class HttpMulti < Base
-    def perform(_user_id, _enc_object_xml, _person_ids, _retry_count=0)
+  class SendPrivate < Base
+    def perform(*_args)
+      # don't federate in cucumber
+    end
+  end
+
+  class SendPublic < Base
+    def perform(*_args)
       # don't federate in cucumber
     end
   end
 
   class PostToService < Base
-    def perform(_service_id, _post_id, _url)
+    def perform(*_args)
       # don't post to services in cucumber
     end
   end
+
+  class FetchWebfinger < Base
+    def perform(*_args)
+      # don't do real discovery in cucumber
+    end
+  end
 end
