@@ -4,9 +4,7 @@
 
 module Diaspora
   module Federated
-    require 'diaspora/federated/request'
-    require 'diaspora/federated/retraction'
-    require 'diaspora/federated/signed_retraction'
-    require 'diaspora/federated/relayable_retraction'
+    require "diaspora/federated/base"
+    require "diaspora/federated/retraction"
   end
-end
\ No newline at end of file
+end
