@@ -7,7 +7,7 @@ require 'spec_helper'
 describe ConversationVisibilitiesController, :type => :controller do
   before do
     @user1 = alice
-    sign_in :user, @user1
+    sign_in @user1, scope: :user
 
     hash = {
       :author => @user1.person,
@@ -27,22 +27,22 @@ describe ConversationVisibilitiesController, :type => :controller do
 
     it 'does not let a user destroy a visibility that is not theirs' do
       user2 = eve
-      sign_in :user, user2
+      sign_in user2, scope: :user
 
       expect {
         delete :destroy, :conversation_id => @conversation.id
       }.not_to change(ConversationVisibility, :count)
     end
-    
+
     it 'returns "hidden"' do
       get :destroy, :conversation_id => @conversation.id
       expect(flash.notice).to include("hidden")
     end
-    
+
     it 'returns "deleted" when last participant' do
       get :destroy, :conversation_id => @conversation.id
       sign_out :user
-      sign_in :user, bob
+      sign_in bob, scope: :user
       get :destroy, :conversation_id => @conversation.id
       expect(flash.notice).to include("deleted")
     end
