@@ -11,7 +11,7 @@ describe ContactsController, :type => :controller do
       @aspect = bob.aspects.create(:name => "another aspect")
       bob.share_with alice.person, @aspect
       bob.share_with eve.person, @aspect
-      sign_in :user, bob
+      sign_in bob, scope: :user
     end
 
     it "generates the aspects_manage fixture", :fixture => true do
@@ -19,6 +19,11 @@ describe ContactsController, :type => :controller do
       save_fixture(html_for("body"), "aspects_manage")
     end
 
+    it "generates the aspects_manage_contacts_json fixture", fixture: true do
+      get :index, format: :json, a_id: @aspect.id, page: "1"
+      save_fixture(response.body, "aspects_manage_contacts_json")
+    end
+
     it "generates the contacts_json fixture", :fixture => true do
       json = bob.contacts.map { |c|
                ContactPresenter.new(c, bob).full_hash_with_person
