@@ -5,8 +5,6 @@
 require "spec_helper"
 
 describe SessionsController, type: :controller do
-  include Devise::TestHelpers
-
   let(:mock_access_token) { Object.new }
 
   before do
@@ -34,7 +32,7 @@ describe SessionsController, type: :controller do
 
   describe "#destroy" do
     before do
-      sign_in :user, @user
+      sign_in @user, scope: :user
     end
     it "redirects to / for a non-mobile user" do
       delete :destroy
@@ -51,7 +49,7 @@ describe SessionsController, type: :controller do
   describe "#reset_authentication_token" do
     context "for a logged in user" do
       before do
-        sign_in :user, @user
+        sign_in @user, scope: :user
       end
 
       it "succeeds" do
