@@ -6,21 +6,17 @@
 describe("app.views.Publisher", function() {
   context("standalone", function() {
     beforeEach(function() {
-      // TODO should be jasmine helper
-      loginAs({name: "alice", avatar : {small : "http://avatar.com/photo.jpg"}});
+      loginAs(factory.userAttrs());
 
       spec.loadFixture("aspects_index");
       this.view = new app.views.Publisher({
         standalone: true
       });
+      this.view.open();
     });
 
     it("hides the close button in standalone mode", function() {
-      expect(this.view.$("#hide_publisher").is(":visible")).toBeFalsy();
-    });
-
-    it("hides the post preview button in standalone mode", function() {
-      expect(this.view.$(".post_preview_button").is(":visible")).toBeFalsy();
+      expect(this.view.$(".md-cancel").is(":visible")).toBeFalsy();
     });
 
     it("hides the manage services link in standalone mode", function() {
@@ -40,13 +36,27 @@ describe("app.views.Publisher", function() {
 
   context("plain publisher", function() {
     beforeEach(function() {
-      // TODO should be jasmine helper
-      loginAs({name: "alice", avatar : {small : "http://avatar.com/photo.jpg"}});
+      loginAs(factory.userAttrs());
 
       spec.loadFixture("aspects_index");
       this.view = new app.views.Publisher();
     });
 
+    describe("#initSubviews", function() {
+      it("calls handleTextchange if the publisher is prefilled with mentions", function() {
+        spyOn(this.view, "handleTextchange");
+        this.view.prefillMention = "user@example.org";
+        this.view.initSubviews();
+        expect(this.view.handleTextchange).toHaveBeenCalled();
+      });
+
+      it("doesn't call handleTextchange if there are no prefilled mentions", function() {
+        spyOn(this.view, "handleTextchange");
+        this.view.initSubviews();
+        expect(this.view.handleTextchange).not.toHaveBeenCalled();
+      });
+    });
+
     describe("#open", function() {
       it("removes the 'closed' class from the publisher element", function() {
         expect($(this.view.el)).toHaveClass("closed");
@@ -76,6 +86,49 @@ describe("app.views.Publisher", function() {
         this.view.close($.Event());
         expect($(this.view.el).find("#status_message_fake_text").attr("style")).not.toContain("height");
       });
+
+      it("should hide the poll container correctly", function() {
+        this.view.$el.find(".poll-creator").click();
+        expect(this.view.$el.find(".publisher-textarea-wrapper")).toHaveClass("with-poll");
+        expect(this.view.$el.find(".poll-creator-container")).toBeVisible();
+        this.view.close();
+        expect(this.view.$el.find(".publisher-textarea-wrapper")).not.toHaveClass("with-poll");
+        expect(this.view.$el.find(".poll-creator-container")).not.toBeVisible();
+        this.view.open();
+        expect(this.view.$el.find(".publisher-textarea-wrapper")).not.toHaveClass("with-poll");
+        expect(this.view.$el.find(".poll-creator-container")).not.toBeVisible();
+        this.view.$el.find(".poll-creator").click();
+        expect(this.view.$el.find(".publisher-textarea-wrapper")).toHaveClass("with-poll");
+        expect(this.view.$el.find(".poll-creator-container")).toBeVisible();
+      });
+
+      it("should close the publisher when clicking outside", function() {
+        expect("#publisher").not.toHaveClass("closed");
+        $("body").click();
+        expect("#publisher").toHaveClass("closed");
+      });
+
+      it("should not close the publisher when clicking inside", function() {
+        expect("#publisher").not.toHaveClass("closed");
+        $("#publisher").find(".publisher-textarea-wrapper").click();
+        expect("#publisher").not.toHaveClass("closed");
+        $("#publisher").find(".aspect_dropdown button").click();
+        expect("#publisher").not.toHaveClass("closed");
+      });
+
+      it("should not close the publisher when clicking inside on a mobile", function() {
+        // Bootstrap inserts a .dropdown-backdrop next to the dropdown menu
+        // that take the whole page when it detects a mobile.
+        // Clicking on this element should not close the publisher.
+        // See https://github.com/diaspora/diaspora/issues/6979.
+        $("#publisher").find(".aspect_dropdown").append("<div class='dropdown-backdrop'></div>")
+          .css({position: "fixed", left: 0, right: 0, bottom: 0, top: 0, "z-index": 990});
+        expect("#publisher").not.toHaveClass("closed");
+        $("#publisher").find(".aspect_dropdown button").click();
+        expect("#publisher").not.toHaveClass("closed");
+        $("#publisher").find(".dropdown-backdrop").click();
+        expect("#publisher").not.toHaveClass("closed");
+      });
     });
 
     describe("#clear", function() {
@@ -86,11 +139,11 @@ describe("app.views.Publisher", function() {
         expect(this.view.close).toHaveBeenCalled();
       });
 
-      it("calls removePostPreview", function(){
-        spyOn(this.view, "removePostPreview");
+      it("calls hidePreview", function() {
+        spyOn(this.view.markdownEditor, "hidePreview");
 
         this.view.clear($.Event());
-        expect(this.view.removePostPreview).toHaveBeenCalled();
+        expect(this.view.markdownEditor.hidePreview).toHaveBeenCalled();
       });
 
       it("clears all textareas", function(){
@@ -109,12 +162,12 @@ describe("app.views.Publisher", function() {
       it("removes all photos from the dropzone area", function(){
         var self = this;
         _.times(3, function(){
-          self.view.el_photozone.append($("<li>"));
+          self.view.photozoneEl.append($("<li>"));
         });
 
-        expect(this.view.el_photozone.html()).not.toBe("");
+        expect(this.view.photozoneEl.html()).not.toBe("");
         this.view.clear($.Event());
-        expect(this.view.el_photozone.html()).toBe("");
+        expect(this.view.photozoneEl.html()).toBe("");
       });
 
       it("removes all photo values appended by the photo uploader", function(){
@@ -134,6 +187,13 @@ describe("app.views.Publisher", function() {
         this.view.clear($.Event());
         expect($("#location").length).toBe(0);
       });
+
+      it("removes the 'submitting' class from the textarea wrapper", function(){
+        this.view.wrapperEl.addClass("submitting");
+        expect(this.view.wrapperEl).toHaveClass("submitting");
+        this.view.clear($.Event());
+        expect(this.view.wrapperEl).not.toHaveClass("submitting");
+      });
     });
 
     describe("createStatusMessage", function(){
@@ -150,35 +210,47 @@ describe("app.views.Publisher", function() {
         jasmine.Ajax.requests.mostRecent().respondWith({ status: 200, responseText: "{\"id\": 1}" });
         expect(app.stream.addNow).toHaveBeenCalled();
       });
+
+      it("adds the 'submitting' class from the textarea wrapper", function(){
+        expect(this.view.wrapperEl).not.toHaveClass("submitting");
+        this.view.createStatusMessage($.Event());
+        expect(this.view.wrapperEl).toHaveClass("submitting");
+      });
+    });
+
+    describe("createPostPreview", function(){
+      it("calls handleTextchange to complete missing mentions", function(){
+        spyOn(this.view, "handleTextchange");
+        this.view.createPostPreview();
+        expect(this.view.handleTextchange).toHaveBeenCalled();
+      });
     });
 
     describe('#setText', function() {
-      it('sets the content text', function() {
-        this.view.setText('FOO bar');
+      it("sets the content text", function() {
+        this.view.setText("FOO bar");
 
-        expect(this.view.el_input.val()).toEqual('FOO bar');
-        expect(this.view.el_hiddenInput.val()).toEqual('FOO bar');
+        expect(this.view.inputEl.val()).toEqual("FOO bar");
+        expect(this.view.hiddenInputEl.val()).toEqual("FOO bar");
       });
     });
 
     describe('#setEnabled', function() {
-      it('disables the publisher', function() {
+      it("disables the publisher", function() {
         expect(this.view.disabled).toBeFalsy();
         this.view.setEnabled(false);
 
         expect(this.view.disabled).toBeTruthy();
-        expect(this.view.el_input.prop('disabled')).toBeTruthy();
-        expect(this.view.el_hiddenInput.prop('disabled')).toBeTruthy();
+        expect(this.view.inputEl.prop("disabled")).toBeTruthy();
+        expect(this.view.hiddenInputEl.prop("disabled")).toBeTruthy();
       });
 
       it("disables submitting", function() {
-        this.view.setText('TESTING');
-        expect(this.view.el_submit.prop('disabled')).toBeFalsy();
-        expect(this.view.el_preview.prop('disabled')).toBeFalsy();
+        this.view.setText("TESTING");
+        expect(this.view.submitEl.prop("disabled")).toBeFalsy();
 
         this.view.setEnabled(false);
-        expect(this.view.el_submit.prop('disabled')).toBeTruthy();
-        expect(this.view.el_preview.prop('disabled')).toBeTruthy();
+        expect(this.view.submitEl.prop("disabled")).toBeTruthy();
       });
     });
 
@@ -189,8 +261,7 @@ describe("app.views.Publisher", function() {
         var submitCallback = jasmine.createSpy().and.returnValue(false);
         form.submit(submitCallback);
 
-        var e = $.Event("keydown", { keyCode: 13 });
-        e.ctrlKey = true;
+        var e = $.Event("keydown", { which: Keycodes.ENTER, ctrlKey: true });
         this.view.keyDown(e);
 
         expect(submitCallback).toHaveBeenCalled();
@@ -199,10 +270,6 @@ describe("app.views.Publisher", function() {
     });
 
     describe("_beforeUnload", function(){
-      beforeEach(function(){
-        Diaspora.I18n.load({ confirm_unload: "Please confirm that you want to leave this page - data you have entered won't be saved."});
-      });
-
       it("calls _submittable", function(){
         spyOn(this.view, "_submittable");
         $(window).trigger('beforeunload');
@@ -301,65 +368,35 @@ describe("app.views.Publisher", function() {
 
   context("aspect selection", function(){
     beforeEach( function(){
-      loginAs({name: "alice", avatar : {small : "http://avatar.com/photo.jpg"}});
+      loginAs(factory.userAttrs());
       spec.loadFixture("status_message_new");
-      Diaspora.I18n.load({ stream: { public: 'Public' }});
 
       this.view = new app.views.Publisher();
       this.view.open();
-
-      this.radio_els = this.view.$('#publisher .aspect_dropdown li.radio');
-      this.check_els = this.view.$('#publisher .aspect_dropdown li.aspect_selector');
-      this.visibility_icon = this.view.$('#visibility-icon');
     });
 
     it("initializes with 'all_aspects'", function(){
-      expect($('.aspect_dropdown li.public')).not.toHaveClass('selected');
-      expect($('.aspect_dropdown li.all_aspects')).toHaveClass('selected');
-      expect($('.aspect_dropdown li.aspect_selector')).not.toHaveClass('selected');
-
-      expect($('#publisher #visibility-icon')).not.toHaveClass('globe');
-      expect($('#publisher #visibility-icon')).toHaveClass('lock');
+      expect($("#publisher #visibility-icon")).not.toHaveClass("entypo-globe");
+      expect($("#publisher #visibility-icon")).toHaveClass("entypo-lock");
     });
 
-    it("toggles the selected entry visually", function(){
-      // click on the first aspect
-      var evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:first') });
-      this.view.view_aspect_selector.toggleAspect(evt);
-      // public and "all aspects" are deselected
-      expect($('.aspect_dropdown li.public')).not.toHaveClass('selected');
-      expect($('.aspect_dropdown li.all_aspects')).not.toHaveClass('selected');
-      // the first aspect is selected
-      expect($('.aspect_dropdown li.aspect_selector:first')).toHaveClass('selected');
-      // the last aspect is not selected
-      expect($('.aspect_dropdown li.aspect_selector:last')).not.toHaveClass('selected');
-      // visibility icon is set to the lock icon
-      expect($('#publisher #visibility-icon')).not.toHaveClass('globe');
-      expect($('#publisher #visibility-icon')).toHaveClass('lock');
+    describe("toggles the selected entry visually", function(){
+      it("click on the first aspect", function(){
+        this.view.$(".aspect_dropdown li.aspect_selector:first").click();
+        expect($("#publisher #visibility-icon")).not.toHaveClass("entypo-globe");
+        expect($("#publisher #visibility-icon")).toHaveClass("entypo-lock");
+      });
 
-      // click on public
-      evt = $.Event("click", { target: $('.aspect_dropdown li.public') });
-      this.view.view_aspect_selector.toggleAspect(evt);
-      // public is selected, "all aspects" is deselected
-      expect($('.aspect_dropdown li.public').hasClass('selected')).toBeTruthy();
-      expect($('.aspect_dropdown li.all_aspects').hasClass('selected')).toBeFalsy();
-      // the aspects are deselected
-      expect($('.aspect_dropdown li.aspect_selector').hasClass('selected')).toBeFalsy();
-      // visibility icon is set to the globe icon
-      expect($('#publisher #visibility-icon').hasClass('globe')).toBeTruthy();
-      expect($('#publisher #visibility-icon').hasClass('lock')).toBeFalsy();
+      it("click on public", function(){
+        this.view.$(".aspect_dropdown li.public").click();
+        expect($("#publisher #visibility-icon")).toHaveClass("entypo-globe");
+        expect($("#publisher #visibility-icon")).not.toHaveClass("entypo-lock");
+      });
 
-      // click on "all aspects"
-      evt = $.Event("click", { target: $('.aspect_dropdown li.all_aspects') });
-      this.view.view_aspect_selector.toggleAspect(evt);
-      // public is deselected, "all aspects" is selected
-      expect($('.aspect_dropdown li.public').hasClass('selected')).toBeFalsy();
-      expect($('.aspect_dropdown li.all_aspects').hasClass('selected')).toBeTruthy();
-      // the aspects are deselected
-      expect($('.aspect_dropdown li.aspect_selector').hasClass('selected')).toBeFalsy();
-      // visibility icon is set to the lock icon
-      expect($('#publisher #visibility-icon').hasClass('globe')).toBeFalsy();
-      expect($('#publisher #visibility-icon').hasClass('lock')).toBeTruthy();
+      it("click on 'all aspects'", function(){
+        expect($("#publisher #visibility-icon")).not.toHaveClass("entypo-globe");
+        expect($("#publisher #visibility-icon")).toHaveClass("entypo-lock");
+      });
     });
 
     describe("hidden form elements", function(){
@@ -373,7 +410,7 @@ describe("app.views.Publisher", function() {
         expect(selected.first().val()).toBe('all_aspects');
 
         var evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:last') });
-        this.view.view_aspect_selector.toggleAspect(evt);
+        this.view.viewAspectSelector.toggleAspect(evt);
 
         selected = $('input[name="aspect_ids[]"]');
         expect(selected.length).toBe(1);
@@ -384,20 +421,20 @@ describe("app.views.Publisher", function() {
         expect($('input[name="aspect_ids[]"][value="42"]').length).toBe(0);
 
         var evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:last') });
-        this.view.view_aspect_selector.toggleAspect(evt);
+        this.view.viewAspectSelector.toggleAspect(evt);
         expect($('input[name="aspect_ids[]"][value="42"]').length).toBe(1);
 
         evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:last') });
-        this.view.view_aspect_selector.toggleAspect(evt);
+        this.view.viewAspectSelector.toggleAspect(evt);
         expect($('input[name="aspect_ids[]"][value="42"]').length).toBe(0);
       });
 
       it("keeps other fields with different values", function() {
         $('.dropdown-menu').append('<li data-aspect_id="99" class="aspect_selector" />');
         var evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:eq(-2)') });
-        this.view.view_aspect_selector.toggleAspect(evt);
+        this.view.viewAspectSelector.toggleAspect(evt);
         evt = $.Event("click", { target: $('.aspect_dropdown li.aspect_selector:eq(-1)') });
-        this.view.view_aspect_selector.toggleAspect(evt);
+        this.view.viewAspectSelector.toggleAspect(evt);
 
         expect($('input[name="aspect_ids[]"][value="42"]').length).toBe(1);
         expect($('input[name="aspect_ids[]"][value="99"]').length).toBe(1);
@@ -407,8 +444,7 @@ describe("app.views.Publisher", function() {
 
   context("locator", function() {
     beforeEach(function() {
-      // should be jasmine helper
-      loginAs({name: "alice", avatar : {small : "http://avatar.com/photo.jpg"}});
+      loginAs(factory.userAttrs());
 
       spec.loadFixture("aspects_index");
       this.view = new app.views.Publisher();
@@ -418,7 +454,7 @@ describe("app.views.Publisher", function() {
       it("Show location", function(){
 
         // inserts location to the DOM; it is the location's view element
-        setFixtures('<div id="location_container"></div>');
+        setFixtures('<div class="location-container"></div>');
 
         // creates a fake Locator
         OSM = {};
@@ -448,8 +484,7 @@ describe("app.views.Publisher", function() {
     describe('#avoidEnter', function(){
       it("Avoid submitting the form when pressing enter", function(){
         // simulates the event object
-        var evt = {};
-        evt.keyCode = 13;
+        var evt = $.Event("keydown", { which: Keycodes.ENTER });
 
         // should return false in order to avoid the form submition
         expect(this.view.avoidEnter(evt)).toBeFalsy();
@@ -466,7 +501,6 @@ describe("app.views.Publisher", function() {
         '    <div id="publisher_textarea_wrapper"></div>'+
         '    <div id="photodropzone"></div>'+
         '    <input type="submit" />'+
-        '    <button class="post_preview_button" />'+
         '  </form></div>'+
         '</div>'
       );
@@ -484,7 +518,7 @@ describe("app.views.Publisher", function() {
         this.view = new app.views.Publisher();
 
         // replace the uploader plugin with a dummy object
-        var upload_view = this.view.view_uploader;
+        var upload_view = this.view.viewUploader;
         this.uploader = {
           onProgress: _.bind(upload_view.progressHandler, upload_view),
           onSubmit:   _.bind(upload_view.submitHandler, upload_view),
@@ -497,7 +531,7 @@ describe("app.views.Publisher", function() {
         it('shows progress in percent', function() {
           this.uploader.onProgress(null, 'test.jpg', 20, 100);
 
-          var info = this.view.view_uploader.el_info;
+          var info = this.view.viewUploader.info;
           expect(info.text()).toContain('test.jpg');
           expect(info.text()).toContain('20%');
         });
@@ -509,19 +543,17 @@ describe("app.views.Publisher", function() {
         });
 
         it('adds a placeholder', function() {
-          expect(this.view.el_wrapper.attr('class')).toContain('with_attachments');
-          expect(this.view.el_photozone.find('li').length).toBe(1);
+          expect(this.view.wrapperEl.attr("class")).toContain("with_attachments");
+          expect(this.view.photozoneEl.find("li").length).toBe(1);
         });
 
         it('disables the publisher buttons', function() {
-          expect(this.view.el_submit.prop('disabled')).toBeTruthy();
-          expect(this.view.el_preview.prop('disabled')).toBeTruthy();
+          expect(this.view.submitEl.prop("disabled")).toBeTruthy();
         });
       });
 
       context('successful completion', function() {
         beforeEach(function() {
-          Diaspora.I18n.load({ photo_uploader: { completed: '<%= file %> completed' }});
           $('#photodropzone').html('<li class="publisher_photo loading"><img src="" /></li>');
 
           this.uploader.onComplete(null, 'test.jpg', {
@@ -533,7 +565,7 @@ describe("app.views.Publisher", function() {
         });
 
         it('shows it in text form', function() {
-          var info = this.view.view_uploader.el_info;
+          var info = this.view.viewUploader.info;
           expect(info.text()).toBe(Diaspora.I18n.t('photo_uploader.completed', {file: 'test.jpg'}));
         });
 
@@ -543,7 +575,7 @@ describe("app.views.Publisher", function() {
         });
 
         it('replaces the placeholder', function() {
-          var li  = this.view.el_photozone.find('li');
+          var li  = this.view.photozoneEl.find("li");
           var img = li.find('img');
 
           expect(li.attr('class')).not.toContain('loading');
@@ -552,14 +584,12 @@ describe("app.views.Publisher", function() {
         });
 
         it('re-enables the buttons', function() {
-          expect(this.view.el_submit.prop('disabled')).toBeFalsy();
-          expect(this.view.el_preview.prop('disabled')).toBeFalsy();
+          expect(this.view.submitEl.prop("disabled")).toBeFalsy();
         });
       });
 
       context('unsuccessful completion', function() {
         beforeEach(function() {
-          Diaspora.I18n.load({ photo_uploader: { completed: '<%= file %> completed' }});
           $('#photodropzone').html('<li class="publisher_photo loading"><img src="" /></li>');
 
           this.uploader.onComplete(null, 'test.jpg', {
@@ -571,7 +601,7 @@ describe("app.views.Publisher", function() {
         });
 
         it('shows error message', function() {
-          var info = this.view.view_uploader.el_info;
+          var info = this.view.viewUploader.info;
           expect(info.text()).toBe(Diaspora.I18n.t('photo_uploader.error', {file: 'test.jpg'}));
         });
       });
@@ -580,21 +610,21 @@ describe("app.views.Publisher", function() {
     context('photo removal', function() {
       beforeEach(function() {
         this.view = new app.views.Publisher();
-        this.view.el_wrapper.addClass('with_attachments');
-        this.view.el_photozone.html(
-          '<li class="publisher_photo">.'+
-          '  <img data-id="444" />'+
-          '  <div class="x">X</div>'+
-          '  <div class="circle"></div>'+
-          '</li>'
+        this.view.wrapperEl.addClass("with_attachments");
+        this.view.photozoneEl.html(
+          "<li class=\"publisher_photo\">."+
+          "  <img data-id=\"444\" />"+
+          "  <div class=\"x\">X</div>"+
+          "  <div class=\"circle\"></div>"+
+          "</li>"
         );
 
         spyOn(jQuery, 'ajax').and.callFake(function(opts) { opts.success(); });
-        this.view.el_photozone.find('.x').click();
+        this.view.photozoneEl.find(".x").click();
       });
 
       it('removes the element', function() {
-        var photo = this.view.el_photozone.find('li.publisher_photo');
+        var photo = this.view.photozoneEl.find("li.publisher_photo");
         expect(photo.length).toBe(0);
       });
 
@@ -603,10 +633,8 @@ describe("app.views.Publisher", function() {
       });
 
       it('removes class on wrapper element', function() {
-        expect(this.view.el_wrapper.attr('class')).not.toContain('with_attachments');
+        expect(this.view.wrapperEl.attr("class")).not.toContain("with_attachments");
       });
     });
   });
-
 });
-
