@@ -18,19 +18,19 @@ describe Publisher do
 
   describe '#text' do
     it 'is a formatted version of the prefill' do
-      p = Publisher.new(alice, :prefill => "@{alice; alice@pod.com}")
+      p = Publisher.new(alice, prefill: "@{alice; #{alice.diaspora_handle}}")
       expect(p.text).to eq("alice")
     end
   end
 
   ["open", "public", "explain"].each do |property|
-    describe "##{property}?" do
+    describe "##{property}" do
       it 'defaults to closed' do
-        expect(@publisher.send("#{property}?".to_sym)).to be_falsey
+        expect(@publisher.send("#{property}".to_sym)).to be_falsey
       end
 
       it 'listens to the opts' do
-        expect(Publisher.new(alice, {property.to_sym => true}).send("#{property}?".to_sym)).to be true
+        expect(Publisher.new(alice, property.to_sym => true).send("#{property}".to_sym)).to be true
       end
     end
   end
