@@ -2,19 +2,26 @@ require 'spec_helper'
 require Rails.root.join('spec', 'shared_behaviors', 'stream')
 
 describe Stream::Person do
-  before do
-    @stream = Stream::Person.new(alice, bob.person, :max_time => Time.now, :order => 'updated_at')
+  describe "shared behaviors" do
+    before do
+      @stream = Stream::Person.new(alice, bob.person, max_time: Time.zone.now, order: "updated_at")
+    end
+
+    it_should_behave_like "it is a stream"
   end
 
-  describe 'shared behaviors' do
-    it_should_behave_like 'it is a stream'
+  describe "#posts" do
+    it "calls user#posts_from if the user is present" do
+      stream = Stream::Person.new(alice, bob.person, max_time: Time.zone.now, order: "updated_at")
+      expect(alice).to receive(:posts_from).with(bob.person)
+      stream.posts
+    end
   end
 
   it "returns the most recent posts" do
-    skip # this randomly fails on postgres
     posts = []
     fetched_posts = []
-    
+
     aspect = bob.aspects.first.id
     Timecop.scale(600) do
       16.times do |n|
@@ -30,5 +37,4 @@ describe Stream::Person do
 
     expect(fetched_posts).to eq(posts)
   end
-
 end
