@@ -25,5 +25,13 @@ describe ContactPresenter do
     it "has relationship information" do
       expect(@presenter.full_hash_with_person[:person][:relationship]).to be(:mutual)
     end
+
+    it "doesn't have redundant contact object in person hash" do
+      expect(@presenter.full_hash_with_person[:person]).not_to have_key(:contact)
+    end
+
+    it "has avatar links in person profile hash" do
+      expect(@presenter.full_hash_with_person[:person][:profile]).to have_key(:avatar)
+    end
   end
 end
