@@ -3,6 +3,10 @@
 #   the COPYRIGHT file.
 
 ENV["RAILS_ENV"] ||= "test"
+
+require 'coveralls'
+Coveralls.wear!('rails')
+
 require File.join(File.dirname(__FILE__), "..", "config", "environment")
 require Rails.root.join("spec", "helper_methods")
 require Rails.root.join("spec", "spec-doc")
@@ -23,10 +27,6 @@ UnprocessedImage.enable_processing = false
 Rails.application.routes.default_url_options[:host] = AppConfig.pod_uri.host
 Rails.application.routes.default_url_options[:port] = AppConfig.pod_uri.port
 
-def set_up_friends
-  [local_luke, local_leia, remote_raphael]
-end
-
 def alice
   @alice ||= User.find_by(username: "alice")
 end
@@ -59,6 +59,29 @@ def photo_fixture_name
   @photo_fixture_name = File.join(File.dirname(__FILE__), "fixtures", "button.png")
 end
 
+def jwks_file_path
+  @jwks_file = File.join(File.dirname(__FILE__), "fixtures", "jwks.json")
+end
+
+def valid_client_assertion_path
+  @valid_client_assertion = File.join(File.dirname(__FILE__), "fixtures", "valid_client_assertion.txt")
+end
+
+def client_assertion_with_tampered_sig_path
+  @client_assertion_with_tampered_sig = File.join(File.dirname(__FILE__), "fixtures",
+                                                  "client_assertion_with_tampered_sig.txt")
+end
+
+def client_assertion_with_nonexistent_kid_path
+  @client_assertion_with_nonexistent_kid = File.join(File.dirname(__FILE__), "fixtures",
+                                                     "client_assertion_with_nonexistent_kid.txt")
+end
+
+def client_assertion_with_nonexistent_client_id_path
+  @client_assertion_with_nonexistent_client_id = File.join(File.dirname(__FILE__), "fixtures",
+                                                           "client_assertion_with_nonexistent_client_id.txt")
+end
+
 # Force fixture rebuild
 FileUtils.rm_f(Rails.root.join("tmp", "fixture_builder.yml"))
 
@@ -70,7 +93,8 @@ support_files.each {|f| require f }
 require fixture_builder_file
 
 RSpec.configure do |config|
-  config.include Devise::TestHelpers, :type => :controller
+  config.include Devise::Test::ControllerHelpers, type: :controller
+  config.include Devise::Test::IntegrationHelpers, type: :request
   config.mock_with :rspec
 
   config.example_status_persistence_file_path = "tmp/rspec-persistance.txt"
@@ -82,10 +106,9 @@ RSpec.configure do |config|
   config.before(:each) do
     I18n.locale = :en
     stub_request(:post, "https://pubsubhubbub.appspot.com/")
-    disable_typhoeus
     $process_queue = false
-    allow_any_instance_of(Postzord::Dispatcher::Public).to receive(:deliver_to_remote)
-    allow_any_instance_of(Postzord::Dispatcher::Private).to receive(:deliver_to_remote)
+    allow(Workers::SendPublic).to receive(:perform_async)
+    allow(Workers::SendPrivate).to receive(:perform_async)
   end
 
   config.expect_with :rspec do |expect_config|
@@ -106,6 +129,11 @@ RSpec.configure do |config|
     ActionMailer::Base.deliveries.clear
   end
 
+  # Reset gon
+  config.after(:each) do
+    RequestStore.store[:gon].gon.clear unless RequestStore.store[:gon].nil?
+  end
+
   config.include FactoryGirl::Syntax::Methods
 end
 
